#
# spec file for package qemu
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qemu
Url:            http://www.qemu.org/
Summary:        Universal CPU emulator
License:        BSD-3-Clause ; GPL-2.0+ ; LGPL-2.1+ ; MIT
Group:          System/Emulators/PC
Version:        1.1rc1
Release:        0
Source:         %name-1.1-rc1.tar.gz
Patch0001:      0001-Handle-CPU-interrupts-by-inline-che.patch
Patch0002:      0002-XXX-dont-dump-core-on-sigabort.patc.patch
Patch0003:      0003-XXX-work-around-SA_RESTART-race-wit.patch
Patch0004:      0004-qemu-0.9.0.cvs-binfmt.patch.patch
Patch0005:      0005-qemu-cvs-alsa_bitfield.patch.patch
Patch0006:      0006-qemu-cvs-alsa_ioctl.patch.patch
Patch0007:      0007-qemu-cvs-alsa_mmap.patch.patch
Patch0008:      0008-qemu-cvs-gettimeofday.patch.patch
Patch0009:      0009-qemu-cvs-ioctl_debug.patch.patch
Patch0010:      0010-qemu-cvs-ioctl_nodirection.patch.patch
Patch0011:      0011-qemu-img-vmdk-scsi.patch.patch
Patch0012:      0012-configure-Enable-mipsn32-linux-user.patch
Patch0013:      0013-linux-user-add-binfmt-wrapper-for-a.patch
Patch0014:      0014-linux-user-Ignore-timer_create-sysc.patch
Patch0015:      0015-linux-user-be-silent-about-capget-f.patch
Patch0016:      0016-PPC-KVM-Disable-mmu-notifier-check..patch
Patch0017:      0017-linux-user-fix-segfault-deadlock.pa.patch
Patch0018:      0018-linux-user-binfmt-support-host-bina.patch
Patch0019:      0019-linux-user-Fix-stale-tbs-after-mmap.patch
# this is to make lint happy
Source300:      rpmlintrc
Source400:      update_git.sh
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  SDL-devel
BuildRequires:  bison
BuildRequires:  bluez-devel
BuildRequires:  curl-devel
BuildRequires:  cyrus-sasl-devel
BuildRequires:  e2fsprogs-devel
BuildRequires:  libaio
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libgnutls-devel
BuildRequires:  libpcap-devel
BuildRequires:  ncurses-devel
%if 0%{?suse_version} >= 1120
BuildRequires:  zlib-devel-static
%else
BuildRequires:  zlib-devel
%endif
%if 0%{?suse_version} >= 1210
BuildRequires:  glibc-devel-static
BuildRequires:  libattr-devel-static
BuildRequires:  libfdt1-devel
%endif
%if 0%{?suse_version} >= 1140
BuildRequires:  glib2-devel-static
%endif
%if 0%{?suse_version} >= 1220
BuildRequires:  pcre-devel-static
%endif
%if 0%{?suse_version} >= 1130
%ifarch %ix86 x86_64
BuildRequires:  libspice-server-devel
BuildRequires:  spice-protocol-devel
%endif
%endif
BuildRequires:  fdupes
BuildRequires:  glib2-devel
BuildRequires:  libvdeplug3-devel
BuildRequires:  python
Requires:       timezone
Requires:       virt-utils

%description
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

%package linux-user
Summary:        Universal CPU emulator -- Linux User binaries
Group:          System/Emulators/PC
Provides:       qemu:%_bindir/qemu-arm

%description linux-user
QEMU is an extremely well-performing CPU emulator that allows you to
choose between simulating an entire system and running userspace
binaries for different architectures under your native operating
system. It currently emulates x86, ARM, PowerPC and SPARC CPUs as well
as PC and PowerMac systems.

This sub package contains static linked binaries for runnign linux-user
emulations. This can be used together with the OBS build script to
run cross architectures builds

%prep
%setup -q -n qemu-1.1-rc1
%patch0001 -p1
%patch0002 -p1
%patch0003 -p1
%patch0004 -p1
%patch0005 -p1
%patch0006 -p1
%patch0007 -p1
%patch0008 -p1
%patch0009 -p1
%patch0010 -p1
%patch0011 -p1
%patch0012 -p1
%patch0013 -p1
%patch0014 -p1
%patch0015 -p1
%patch0016 -p1
%patch0017 -p1
%patch0018 -p1
%patch0019 -p1

%build
# build QEMU
mkdir -p dynamic
# build qemu-system
./configure --prefix=%_prefix --sysconfdir=%_sysconfdir \
	--interp-prefix=%_datadir/%name/qemu-i386 \
	--audio-card-list="ac97 es1370 sb16 cs4231a adlib gus" \
	--audio-drv-list="alsa sdl" --enable-mixemu --enable-vde \
	--extra-cflags="$QEMU_OPT_FLAGS" --enable-system --disable-linux-user \
        --enable-curl \
%if 0%{?suse_version} >= 1130
%ifarch %ix86 x86_64
	--enable-spice
%else
	--disable-spice
%endif
%else
	--disable-spice
%endif
make %{?jobs:-j%jobs} V=1
make qemu-img V=1
mv *-softmmu/qemu-system-* qemu-io qemu-bridge-helper dynamic || true
make clean
# build userland emus
./configure --prefix=%_prefix --sysconfdir=%_sysconfdir \
	--interp-prefix=%_datadir/%name/qemu-i386 \
	--enable-linux-user \
	--disable-system \
	--static --disable-linux-aio \
	--extra-cflags="$QEMU_OPT_FLAGS"
%if 0%{?suse_version} == 1140
# -lrt needs to come after -lglib-2.0 to avoid undefined clock_gettime
sed -i "s/-lglib-2.0/-lglib-2.0 -lrt/" config-host.mak
%endif
make %{?jobs:-j%jobs} V=1

%install
make install DESTDIR=$RPM_BUILD_ROOT libexecdir=%_libexecdir
rm -f $RPM_BUILD_ROOT/%_mandir/man1/qemu-img.1
rm -f $RPM_BUILD_ROOT/%_mandir/man8/qemu-nbd.8
rm -fr $RPM_BUILD_ROOT/%_datadir/doc
install -m 755 dynamic/qemu-system-* $RPM_BUILD_ROOT/%_bindir
install -m 755 dynamic/qemu-io $RPM_BUILD_ROOT/%_bindir
install -d -m 755 $RPM_BUILD_ROOT/%_sbindir
install -m 755 scripts/qemu-binfmt-conf.sh $RPM_BUILD_ROOT/%_sbindir
install -d -m 755 $RPM_BUILD_ROOT/%_libexecdir
install -m 755 dynamic/qemu-bridge-helper $RPM_BUILD_ROOT/%_libexecdir
%ifnarch %ix86 x86_64
ln -sf ../../../emul/ia32-linux $RPM_BUILD_ROOT/usr/share/qemu/qemu-i386
%endif
%ifnarch ia64
mkdir -p $RPM_BUILD_ROOT/emul/ia32-linux
%endif
%fdupes -s $RPM_BUILD_ROOT

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(-, root, root)
%doc COPYING COPYING.LIB Changelog README TODO VERSION qemu-doc.html qemu-tech.html
%_bindir/qemu-io
%_bindir/qemu-system-*
%_libexecdir/qemu-bridge-helper
%doc %_mandir/man[18]/qemu*.[18].gz
%_datadir/%name
%ifnarch %ix86 x86_64 ia64
%dir /emul/ia32-linux
%endif
%dir %_sysconfdir/%name
%config %_sysconfdir/%name/target-x86_64.conf

%files linux-user
%defattr(-, root, root)
%_bindir/qemu-alpha
%_bindir/qemu-arm
%_bindir/qemu-armeb
%_bindir/qemu-cris
%_bindir/qemu-i386
%_bindir/qemu-m68k
%_bindir/qemu-microblaze
%_bindir/qemu-microblazeel
%_bindir/qemu-mips
%_bindir/qemu-mipsel
%_bindir/qemu-mipsn32
%_bindir/qemu-mipsn32el
%_bindir/qemu-ppc64abi32
%_bindir/qemu-ppc64
%_bindir/qemu-ppc
%_bindir/qemu-s390x
%_bindir/qemu-sh4
%_bindir/qemu-sh4eb
%_bindir/qemu-sparc32plus
%_bindir/qemu-sparc64
%_bindir/qemu-sparc
%_bindir/qemu-unicore32
%_bindir/qemu-x86_64
%_bindir/qemu-*-binfmt
%_sbindir/qemu-binfmt-conf.sh

%changelog
